==> component_builder-2.2.0.tar.gz: component_builder/components/component_carousel/assets/style.js <==
/**
 * @file
 * Javascript functionality for component carousel.
 */

(function ($, Drupal) {

  'use strict';

  Drupal.componentCarousel = Drupal.componentCarousel || {};
  Drupal.behaviors.carousel = {
    attach: function (context) {
      Drupal.componentCarousel.carouselImages(context);
      Drupal.componentCarousel.carouselHiddenFields();
    }
  }

  Drupal.componentCarousel.carouselImages = function (context) {
    var $carousels = $('.component-builder.component-wrapper--type-carousel', context).once('wrapperCarousel');
    let showDot = false;
    if ($carousels.length > 0) {
      $carousels.each(function () {
        var $this = $(this);
        const number = $this.attr('data-carousel-columns') || 2;
        const dot = $this.attr('data-show-dot');
        if(dot == 'true') {
          showDot = true;
        }
        else if(dot == 'false') {
          showDot = false;
        }
        else {
          showDot = false;
        }
        var $items = $this.find('.component-wrapper--content > .field--name-field-carousel.field__items');
        Drupal.componentCarousel.carouselImageSlide($items, number,showDot);
      })
    }
  }

  Drupal.componentCarousel.carouselImageSlide = function ($selector, numberShow = 2, showDot = false) {
    if ($selector.length > 0) {
      if ($selector.find('.field__item').length <= numberShow) {
        showDot = false;
      }
      // console.log(numberShow);
      // console.log($selector.find('.field__item').length);
      $selector.not('.slick-initialized').slick({
        dots: showDot,
        infinite: true,
        speed: 300,
        slidesToShow: numberShow,
        slidesToScroll: 1,
        responsive: [
          {
            breakpoint: 1024,
            settings: {
              slidesToShow: numberShow,
              slidesToScroll: 2,
              infinite: true,
              dots: showDot
            }
          },
          {
            breakpoint: 768,
            settings: {
              slidesToShow: 1,
              slidesToScroll: 1
            }
          },
          {
            breakpoint: 480,
            settings: {
              slidesToShow: 1,
              slidesToScroll: 1
            }
          }
        ]
      });
    }
  }

  Drupal.componentCarousel.carouselHiddenFields = function (context) {
    var $carouselItems = $('.component-builder.component-wrapper--type-carousel', context).once('hiddenFields');
    if ($carouselItems.length > 0) {
      $carouselItems.each(function () {
        var $this = $(this);
        var $hidden_fields = $this.attr('data-hidden-field') || "";
        if ($hidden_fields) {
          $hidden_fields = JSON.parse($hidden_fields);
          $($this.find('.slick-slide')).each(function () {
            for (let i = 0; i < $hidden_fields.length; i++) {
              $(this).find('.field--name-' + $hidden_fields[i].replace("_", "-")).each(function () {
                $(this).css("display", "none");
              });
            }
          });
        }
      })
    }
  }

})(jQuery, Drupal);

==> component_builder-2.2.2.tar.gz: component_builder/components/component_carousel/assets/style.js <==
/**
 * @file
 * Javascript functionality for component carousel.
 */

(function ($, Drupal) {

  'use strict';

  Drupal.componentCarousel = Drupal.componentCarousel || {};
  Drupal.behaviors.carousel = {
    attach: function (context) {
      Drupal.componentCarousel.carouselImages(context);
      Drupal.componentCarousel.carouselHiddenFields();
    }
  }

  Drupal.componentCarousel.carouselImages = function (context) {
    var $carousels = $('.component-builder.component-wrapper--type-carousel', context).once('wrapperCarousel');
    let showDot = false;
    if ($carousels.length > 0) {
      $carousels.each(function () {
        var $this = $(this);
        const number = $this.attr('data-carousel-columns') || 2;
        const dot = $this.attr('data-show-dot');
        if (dot == 'true') {
          showDot = true;
        } else if (dot == 'false') {
          showDot = false;
        } else {
          showDot = false;
        }
        var $items = $this.find('.component-wrapper--content > .field--name-field-carousel.field__items');
        Drupal.componentCarousel.carouselImageSlide($items, number, showDot);
      })
    }
  }

  Drupal.componentCarousel.carouselImageSlide = function ($selector, numberShow = 2, showDot = false) {
    if ($selector.length > 0) {
      if ($selector.find('.field__item').length <= numberShow) {
        showDot = false;
      }
      $selector.not('.slick-initialized').slick({
        dots: showDot,
        rtl: drupalSettings['components']['carousel']['rtl'],
        infinite: true,
        speed: 300,
        slidesToShow: numberShow,
        slidesToScroll: 1,
        responsive: [
          {
            breakpoint: 1024,
            settings: {
              slidesToShow: numberShow,
              slidesToScroll: 2,
              infinite: true,
              dots: showDot
            }
          },
          {
            breakpoint: 768,
            settings: {
              slidesToShow: 1,
              slidesToScroll: 1
            }
          },
          {
            breakpoint: 480,
            settings: {
              slidesToShow: 1,
              slidesToScroll: 1
            }
          }
        ]
      });
    }
  }

  Drupal.componentCarousel.carouselHiddenFields = function (context) {
    var $carouselItems = $('.component-builder.component-wrapper--type-carousel', context).once('hiddenFields');
    if ($carouselItems.length > 0) {
      $carouselItems.each(function () {
        var $this = $(this);
        var $hidden_fields = $this.attr('data-hidden-field') || "";
        if ($hidden_fields) {
          $hidden_fields = JSON.parse($hidden_fields);
          $($this.find('.slick-slide')).each(function () {
            for (let i = 0; i < $hidden_fields.length; i++) {
              $(this).find('.field--name-' + $hidden_fields[i].replace("_", "-")).each(function () {
                $(this).css("display", "none");
              });
            }
          });
        }
      })
    }
  }

})(jQuery, Drupal);
